# ITS_us

ITS_us is a robust package for performing arbitrary single and two qubit quantum operations, structured to intuitively construct quantum circuits.

## Contributors

- Sara Cender
- Theo Iosif
- Ivan Shalashilin

# Notebook examples

Also available in HTML form in the `docs/build/` folder

- [Using `States`](https://github.com/QC2-python-SE/ITS_us/blob/main/docs/source/states_example.ipynb)
- [Using `Gates`](https://github.com/QC2-python-SE/ITS_us/blob/main/docs/source/gates_example.ipynb)
- [Using `Circuits` - Constructing the Bell states](https://github.com/QC2-python-SE/ITS_us/blob/main/docs/source/bell_circuit.ipynb)



# Installation

The latest version of ITS_us can be installed via cloning this repository:

```bash
git clone https://github.com/QC2-python-SE/ITS_us/
```
Complete Documentation may be found in HTML form in the `docs/build/` folder



